==> syncfusion_flutter_maps-18.2.44-beta.tar.gz: lib/src/maps.dart <==
part of maps;

/// Renders the GeoJSON data as a geographical area.
///
/// The maps has the following elements and features,
///
/// * The "data labels", to provide information to users about the respective
/// shape.
/// * The "markers", which denotes a location with built-in symbols and allows
/// displaying custom widgets at a specific latitude and longitude on a map.
/// * The "bubbles", which adds information to shapes such as population
/// density, number of users, and more. Bubbles can be rendered in different
/// colors and sizes based on the data values of their assigned shape.
/// * The "legend", to provide clear information on the data plotted in the map.
/// You can use the legend toggling feature to visualize only the shapes to
/// which the legend applies.
/// * The "color mapping", to categorize the shapes on a map by customizing
/// their color based on the underlying value. It is possible to set the shape
/// color for a specific value or for a range of values.
/// * The "tooltip", to display additional information about shapes and bubbles
/// using the customizable tooltip on a map.
/// * Along with this, the selection feature helps to highlight that area on a
/// map on interaction. You can use the callback for performing any action
/// during shape selection.
///
/// The [layers] in [SfMaps] contains collection of [MapShapeLayer].
/// The actual geographical rendering is done in the each [MapShapeLayer].
///
/// The [MapShapeLayer.delegate] is of type
/// [MapShapeLayerDelegate]. The path of the .json file which contains the
/// GeoJSON data has to be set to the [MapShapeLayerDelegate.shapeFile] property
/// of the [MapShapeLayerDelegate].
///
/// The [shapeDataField] property of the [MapShapeLayerDelegate] is used to
/// refer the unique field name in the .json file to identify each shapes and
/// map with the respective data in the data source.
///
/// The properties in [MapShapeLayer] is used for enabling the features like
/// data labels, tooltip, bubbles, legends, and selection.
/// The properties in [MapShapeLayerDelegate] is used for providing data for the
/// above mentioned elements.
///
/// ## Example
///
/// This snippet shows how to create the [SfMaps].
/// ```dart
///   @override
///  Widget build(BuildContext context) {
///    return Container(
///        child: const SfMaps(
///          layers: [
///            const MapShapeLayer(
///              delegate: const MapShapeLayerDelegate(
///                  shapeFile: "assets/world_map.json",
///                  shapeDataField: "continent"),
///            )
///          ],
///        ));
///     }
/// ```
///
/// See also:
///
/// * [MapShapeLayer] for enabling the features like data labels, tooltip,
/// bubbles, legends, selection etc.
/// * [MapShapeLayerDelegate] for providing data for the elements like data
/// labels, tooltip, bubbles, legends etc.

class SfMaps extends StatefulWidget {
  const SfMaps({
    Key key,
    this.title,
    this.layers,
  }) : super(key: key);

  /// Title for the [SfMaps].
  final MapTitle title;

  final List<MapLayer> layers;

  @override
  _SfMapsState createState() => _SfMapsState();
}

class _SfMapsState extends State<SfMaps> {
  @override
  Widget build(BuildContext context) {
    SyncfusionLicense.validateLicense(context);
    assert(widget.layers != null && widget.layers.isNotEmpty);
    return _MapsRenderObjectWidget(
      child: widget.title != null && widget.title.text != null
          ? Column(
              children: <Widget>[
                _title(context),
                Expanded(
                  child: LayoutBuilder(builder: (_, __) {
                    return Stack(
                      alignment: Alignment.center,
                      children: <Widget>[widget.layers.last],
                    );
                  }),
                ),
              ],
            )
          : Stack(
              alignment: Alignment.center,
              children: <Widget>[widget.layers.last],
            ),
    );
  }

  /// Returns the title of the [SfMaps].
  Widget _title(BuildContext context) {
    final SfMapsThemeData mapsThemeData = SfMapsTheme.of(context);
    return Align(
      alignment: widget.title.alignment ?? Alignment.center,
      child: Container(
        child: Text(
          widget.title.text,
          style: widget.title.textStyle ??
              mapsThemeData.titleTextStyle ??
              Theme.of(context).textTheme.subtitle1,
        ),
        color: widget.title.color,
        decoration: widget.title.decoration,
        margin: widget.title.margin,
        padding:
            widget.title.padding ?? const EdgeInsets.symmetric(vertical: 8),
      ),
    );
  }
}

class _MapsRenderObjectWidget extends SingleChildRenderObjectWidget {
  const _MapsRenderObjectWidget({Key key, Widget child})
      : super(key: key, child: child);

  @override
  _RenderMaps createRenderObject(BuildContext context) {
    return _RenderMaps();
  }
}

class _RenderMaps extends RenderProxyBox {
  @override
  void performLayout() {
    final double width =
        constraints.hasBoundedWidth ? constraints.maxWidth : 300;
    final double height =
        constraints.hasBoundedHeight ? constraints.maxHeight : 300;
    child.layout(BoxConstraints.loose(Size(width, height)),
        parentUsesSize: true);
    size = child.size;
  }
}

==> syncfusion_flutter_maps-18.2.54-beta.tar.gz: lib/src/maps.dart <==
part of maps;

/// Renders the GeoJSON data as a geographical area.
///
/// The maps has the following elements and features,
///
/// * The "data labels", to provide information to users about the respective
/// shape.
/// * The "markers", which denotes a location with built-in symbols and allows
/// displaying custom widgets at a specific latitude and longitude on a map.
/// * The "bubbles", which adds information to shapes such as population
/// density, number of users, and more. Bubbles can be rendered in different
/// colors and sizes based on the data values of their assigned shape.
/// * The "legend", to provide clear information on the data plotted in the map.
/// You can use the legend toggling feature to visualize only the shapes to
/// which needs to be visualized.
/// * The "color mapping", to categorize the shapes on a map by customizing
/// their color based on the underlying value. It is possible to set the shape
/// color for a specific value or for a range of values.
/// * The "tooltip", to display additional information about shapes and bubbles
/// using the customizable tooltip on a map.
/// * Along with this, the selection feature helps to highlight that area on a
/// map on interaction. You can use the callback for performing any action
/// during shape selection.
///
/// The [SfMaps.layers] is a collection of [MapShapeLayer].
///
/// The actual geographical rendering is done in each [MapShapeLayer] using the
/// [MapShapeLayer.delegate]. The path of the .json file which contains the
/// GeoJSON data has to be set to the [MapShapeLayerDelegate.shapeFile].
///
/// The [MapShapeLayerDelegate.shapeDataField] property is used to
/// refer the unique field name in the .json file to identify each shapes and
/// map with the respective data in the data source.
///
/// By default, the value specified for the
/// [MapShapeLayerDelegate.shapeDataField] in the GeoJSON file will be used in
/// the elements like data labels, tooltip, and legend for their respective
/// shapes.
///
/// However, it is possible to keep a data source and customize these elements
/// based on the requirement. The value of the
/// [MapShapeLayerDelegate.shapeDataField] will be used to map with the
/// respective data returned in [MapShapeLayerDelegate.primaryValueMapper]
/// from the data source.
///
/// Once the above mapping is done, you can customize the elements using the
/// APIs like [MapShapeLayerDelegate.dataLabelMapper],
/// [MapShapeLayerDelegate.shapeColorMappers],
/// [MapShapeLayerDelegate.shapeTooltipTextMapper], etc.
///
/// ## Example
///
/// This snippet shows how to create the [SfMaps].
/// ```dart
///   @override
///  Widget build(BuildContext context) {
///    return Container(
///        child: const SfMaps(
///          layers: [
///            const MapShapeLayer(
///              delegate: const MapShapeLayerDelegate(
///                  shapeFile: "assets/world_map.json",
///                  shapeDataField: "continent"),
///            )
///          ],
///        ));
///     }
/// ```
///
/// See also:
///
/// * [MapShapeLayer], for enabling the features like data labels, tooltip,
/// bubbles, legends, selection etc.
/// * [MapShapeLayerDelegate], for providing the data for the elements like data
/// labels, tooltip, bubbles, legends etc.

class SfMaps extends StatefulWidget {
  const SfMaps({
    Key key,
    this.title,
    this.layers,
  }) : super(key: key);

  /// Title for the [SfMaps].
  ///
  /// It can define and customize the title for the [SfMaps]. The text
  /// property of the [MapTitle] is used to set the text of the title.
  ///
  /// It also provides option for customizing text style, alignment, decoration,
  /// background color, margin and padding of the title.
  ///
  /// ```dart
  ///  @override
  ///  Widget build(BuildContext context) {
  ///    return SfMaps(
  ///      title: MapTitle(
  ///        text : 'World map'
  ///      ),
  ///    );
  ///  }
  /// ```
  final MapTitle title;

  /// The collection of map shape layer in which geographical rendering is done.
  ///
  /// The snippet below shows how to render the basic world map using the data
  /// from .json file.
  ///
  /// ```dart
  ///   @override
  ///  Widget build(BuildContext context) {
  ///    return SfMaps(
  ///      layers: [
  ///        MapShapeLayer(
  ///          delegate: MapShapeLayerDelegate(
  ///              shapeFile: "assets/world_map.json",
  ///              shapeDataField: "name",
  ///           ),
  ///        )
  ///      ],
  ///    );
  ///  }
  /// ```
  /// See also:
  /// * [MapShapeLayer.delegate], to provide data for the elements of the
  /// [SfMaps] like data labels, bubbles, tooltip, shape colors, and legend.
  final List<MapLayer> layers;

  @override
  _SfMapsState createState() => _SfMapsState();
}

class _SfMapsState extends State<SfMaps> {
  @override
  Widget build(BuildContext context) {
    SyncfusionLicense.validateLicense(context);
    assert(widget.layers != null && widget.layers.isNotEmpty);
    return _MapsRenderObjectWidget(
      child: widget.title != null && widget.title.text != null
          ? Column(
              children: <Widget>[
                _title(context),
                Expanded(
                  child: LayoutBuilder(builder: (_, __) {
                    return Stack(
                      alignment: Alignment.center,
                      children: <Widget>[widget.layers.last],
                    );
                  }),
                ),
              ],
            )
          : Stack(
              alignment: Alignment.center,
              children: <Widget>[widget.layers.last],
            ),
    );
  }

  /// Returns the title of the [SfMaps].
  Widget _title(BuildContext context) {
    final SfMapsThemeData mapsThemeData = SfMapsTheme.of(context);
    return Align(
      alignment: widget.title.alignment ?? Alignment.center,
      child: Container(
        child: Text(
          widget.title.text,
          style: widget.title.textStyle ??
              mapsThemeData.titleTextStyle ??
              Theme.of(context).textTheme.subtitle1,
        ),
        color: widget.title.color,
        decoration: widget.title.decoration,
        margin: widget.title.margin,
        padding:
            widget.title.padding ?? const EdgeInsets.symmetric(vertical: 8),
      ),
    );
  }
}

class _MapsRenderObjectWidget extends SingleChildRenderObjectWidget {
  const _MapsRenderObjectWidget({Key key, Widget child})
      : super(key: key, child: child);

  @override
  _RenderMaps createRenderObject(BuildContext context) {
    return _RenderMaps();
  }
}

class _RenderMaps extends RenderProxyBox {
  @override
  void performLayout() {
    final double width =
        constraints.hasBoundedWidth ? constraints.maxWidth : 300;
    final double height =
        constraints.hasBoundedHeight ? constraints.maxHeight : 300;
    child.layout(BoxConstraints.loose(Size(width, height)),
        parentUsesSize: true);
    size = child.size;
  }
}
